@@ -1,6 +1,6 @@
 package Protocol::XMPP::Element::Challenge;
 BEGIN {
-  $Protocol::XMPP::Element::Challenge::VERSION = '0.003';
+  $Protocol::XMPP::Element::Challenge::VERSION = '0.004';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -12,7 +12,7 @@ Protocol::XMPP::Challenge - deal with the XMPP challenge
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -50,4 +50,14 @@ sub end_element {
 	$self;
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
