@@ -1,6 +1,6 @@
 package Protocol::XMPP::Element::Feature;
 BEGIN {
-  $Protocol::XMPP::Element::Feature::VERSION = '0.003';
+  $Protocol::XMPP::Element::Feature::VERSION = '0.004';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -12,7 +12,7 @@ Protocol::XMPP::Feature - register ability to deal with a specific feature
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ sub new {
 	$self->debug("Had feature [" . ($feature || 'undef') . "]");
 }
 
-=head2 C<end_element>
+=head2 end_element
 
 =cut
 
@@ -42,4 +42,14 @@ sub end_element {
 	my $self = shift;
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
