@@ -1,6 +1,6 @@
 package Protocol::XMPP::Element::JID;
 BEGIN {
-  $Protocol::XMPP::Element::JID::VERSION = '0.003';
+  $Protocol::XMPP::Element::JID::VERSION = '0.004';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -12,7 +12,7 @@ use parent qw(Protocol::XMPP::TextElement);
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -24,9 +24,18 @@ sub on_text_complete {
 	my $self = shift;
 	my $data = shift;
 	$self->{jid} = $data;
+	$self->stream->jid($data);
 	$self->debug("Full JID was [$data]");
-	# $self->stream->queue_write(q{<iq type='set' id='purple9921ba3c'><session xmlns='urn:ietf:params:xml:ns:xmpp-session'/></iq>});
-	# $self->write_xml([ 'iq', type => 'set', id => 'xyz', _content => [ [ 'session', _ns => 'xmpp-session' ] ] ]);
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
