@@ -1,6 +1,6 @@
 package Protocol::XMPP::Element::Presence;
 BEGIN {
-  $Protocol::XMPP::Element::Presence::VERSION = '0.003';
+  $Protocol::XMPP::Element::Presence::VERSION = '0.004';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -14,7 +14,7 @@ Protocol::XMPP::Success - indicate success for an operation
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -35,4 +35,14 @@ sub end_element {
 	$self->dispatch_event('presence', $contact);
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
