@@ -1,6 +1,6 @@
 package Protocol::XMPP::IQ::Roster;
 BEGIN {
-  $Protocol::XMPP::IQ::Roster::VERSION = '0.003';
+  $Protocol::XMPP::IQ::Roster::VERSION = '0.004';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -12,7 +12,7 @@ use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -115,4 +115,14 @@ Requesting a new contact will cause the server to send out an ask request:
 
 =cut
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
