@@ -1,6 +1,6 @@
 package Protocol::XMPP::User;
 BEGIN {
-  $Protocol::XMPP::User::VERSION = '0.003';
+  $Protocol::XMPP::User::VERSION = '0.004';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -23,3 +23,14 @@ sub roster {
 }
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@entitymodel.com>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
+
